@@ -2,7 +2,7 @@
 
     Main file for  devfsd  (devfs daemon for Linux).
 
-    Copyright (C) 1998-2001  Richard Gooch
+    Copyright (C) 1998-2002  Richard Gooch
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -230,9 +230,16 @@
     Updated by      Richard Gooch   28-NOV-2001: Renamed <make_symlink> to
   <mksymlink> and made it global. Changed to return 0 on "success".
 
-    Last updated by Richard Gooch   29-NOV-2001: Changed <action_copy> to set
+    Updated by      Richard Gooch   29-NOV-2001: Changed <action_copy> to set
   sticky bit as required. Added "RESTORE" key.
 
+    Updated by      Richard Gooch   1-JAN-2002: Changed to extended regular
+  expressions.
+
+    Last updated by Richard Gooch   14-JAN-2002: Fixed dummy opens of
+  /dev/null so that fds [0:2] are open (was only doing fds [0:1]) and prevent
+  infinite loop if /dev/null cannot be opened.
+
 
 */
 #define _GNU_SOURCE
@@ -535,7 +542,8 @@ int main (int argc, char **argv)
     }
     /*  Open dummy stdin, stdout and stderr if required, so that closing in
 	do_open_syslog() doesn't close other files  */
-    while ( ( fd = open ("/dev/null", O_RDWR, 0) ) < 2 );
+    do fd = open ("/dev/null", O_RDWR, 0);
+    while ( (fd >= 0) && (fd < 3) );
     close (fd);
     if ( ( fd = open (".devfsd", O_RDONLY, 0) ) < 0 )
     {
@@ -607,12 +615,12 @@ int main (int argc, char **argv)
 	exit (1);
     }
     if (trace_level < 1)
-    	fprintf (stderr, "Started device management daemon for %s\n",
-		 mount_point);
+    	fprintf (stderr, "Started device management daemon v%s for %s\n",
+		 DEVFSD_VERSION, mount_point);
     else
     	fprintf (stderr,
-		 "Started device management daemon for %s at trace level %d\n",
-		 mount_point, trace_level);
+		 "Started device management daemon v%s for %s at trace level %d\n",
+		 DEVFSD_VERSION, mount_point, trace_level);
     read_config (CONFIG_FILE, FALSE, &event_mask);
     /*  Do the scan before forking, so that boot scripts see the finished
 	product  */
@@ -942,7 +950,7 @@ static void process_config_line (CONST char *line, unsigned long *event_mask)
 	SYSLOG (LOG_ERR, "exiting\n");
 	exit (1);
     }
-    if ( ( err = regcomp (&new->preg, name, 0) ) != 0 )
+    if ( ( err = regcomp (&new->preg, name, REG_EXTENDED) ) != 0 )
     {
 	regerror (err, &new->preg, tmp, STRING_LENGTH);
 	SYSLOG (LOG_ERR, "error compiling regexp: \"%s\"\t%s\n", name,tmp);
